#ifndef NT2_INCLUDE_FUNCTIONS_NBD_ATAN2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NBD_ATAN2_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/nbd_atan2.hpp>

#endif
